@@ -37,6 +37,12 @@ class UpdateStackInstancesRequest(RpcRequest):
 	def set_ClientToken(self,ClientToken):
 		self.add_query_param('ClientToken',ClientToken)
 
+	def get_TimeoutInMinutes(self):
+		return self.get_query_params().get('TimeoutInMinutes')
+
+	def set_TimeoutInMinutes(self,TimeoutInMinutes):
+		self.add_query_param('TimeoutInMinutes',TimeoutInMinutes)
+
 	def get_StackGroupName(self):
 		return self.get_query_params().get('StackGroupName')
 
@@ -68,7 +74,7 @@ class UpdateStackInstancesRequest(RpcRequest):
 		self.add_query_param('AccountIds',AccountIds)
 
 	def get_ParameterOverridess(self):
-		return self.get_query_params().get('ParameterOverridess')
+		return self.get_query_params().get('ParameterOverrides')
 
 	def set_ParameterOverridess(self, ParameterOverridess):
 		for depth1 in range(len(ParameterOverridess)):
